==> wowwotlk-6.x-1.1.tar.gz: wowwotlk/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.1 2009/02/05 17:22:38 magicmatze Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
  <title><?php print $head_title; ?></title>
	<?php print $head; ?>
	<?php print $styles; ?>
	<style type="text/css" media="screen">
		#page { background: url("themes/wowwotlk/images/kubrickbg-ltr.jpg") repeat-y top; border: none; padding-left:0px; }
	</style>
	<?php print $scripts; ?>
</head>

<body>
 <div style="position:absolute; margin-left:-13px; width: 176px; height: 575px;">
<a href="<?php print $front_page ?>" Title="<?php print t('Home') ?>"><img src="themes/wowwotlk/images/lichking.jpg"></a>
</div>

<div class="book" style="position:absolute; padding-left:0px;margin-top:580px; width: 150px; height: 400px;" ><!-- START LEFT SIDEBAR -->
  		<?php if ($left) { ?><div class="sidebar left" ><?php print $left ?></div><?php } ?>
</div><!-- ENDE LEFT SIDEBAR -->
<div id="page"><!-- START PAGE -->


<div id="header"><!-- START HEADER -->
	<div id="headerimg">
		<h1><?php print $site_name; print " - ". $site_slogan ?></h1>
		</h1>
		<div class="description"><?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links) ?><?php } ?></div>
	</div>
</div><!-- ENDE HEADER -->
<hr />

	


      				

	<div id="content" class="narrowcolumn" ><!-- START CONTENT-->
		  <?php print $breadcrumb ?>
          <?php if ($title) { ?><h1 class="title"><?php print $title ?></h1><?php } ?>
          <?php if ($tabs) { ?><div class="tabs"><?php print $tabs ?></div><?php } ?>
          <?php print $help ?>
          <?php print $messages ?>
          <?php print $content; ?>
          <?php print $feed_icons; ?>		
  
	</div><!-- ENDE CONTENT -->




  
  	<div id="sidebar"><!-- START SIDEBAR-->
		<ul>
			<li>
			<?php if ($right) { ?><div><?php print $right ?></div><?php } ?> 
			</li>
		</ul>
	</div><!-- ENDE SIDEBAR -->


<div id="footer"><!-- START FOOTER -->

	<div style="padding-left:240px; text-align:center">
	  <p>
	  	<?php if ($footer_message) : ?>
	      <?php print $footer_message ?>
	    <?php endif ?>
		<br />
	    WebDesign by <a href="http://www.nunodesign.de/">nunodesign</a> &#124; <a href="http://www.randyrun.com">WoW Gold</a> Reseller &#124; ported to Drupal by <a href="http://www.mathiasdittrich.de">Mathias Dittrich</a>
  </p></div>
</div><!-- ENDE FOOTER -->

</div><!-- ENDE PAGE -->

</body>
</html>

==> wowwotlk-6.x-1.2.tar.gz: wowwotlk/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.3 2009/02/15 13:26:08 magicmatze Exp $
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
  <title><?php print $head_title; ?></title>
	<?php print $head; ?>
	<?php print $styles; ?>
	<style type="text/css" media="screen">
		#page { background: url("themes/wowwotlk/images/kubrickbg-ltr.jpg") repeat-y top; border: none; padding-left:0px; }
	</style>
	
	<!--[if gte IE 5.5]>
<![if lt IE 7]>
<style type="text/css">
div#fixme {
  /* IE5.5+/Win - this is more specific than the IE 5.0 version */
  left: expression( ( 20 + ( ignoreMe2 = document.documentElement.scrollLeft ? document.documentElement.scrollLeft : document.body.scrollLeft ) ) + 'px' );
  top: expression( ( 10 + ( ignoreMe = document.documentElement.scrollTop ? document.documentElement.scrollTop : document.body.scrollTop ) ) + 'px' );
}
</style>
<![endif]>
<![endif]-->
	<?php print $scripts; ?>
</head>

<body>
 <div class="king">
<a href="<?php print $front_page ?>" Title="<?php print t('Home') ?>"><img src="themes/wowwotlk/images/lichking.jpg"></a>
</div>

<div class="wowleftsidebar"><!-- START LEFT SIDEBAR -->
  		<?php if ($left) { ?><div class="sidebar left" ><?php print $left ?></div><?php } ?>
</div><!-- ENDE LEFT SIDEBAR -->
<div id="page"><!-- START PAGE -->


<div id="header"><!-- START HEADER -->
	<div id="headerimg">
		<h1><?php print $site_name; ?> - <?php print $site_slogan ?></h1>
		</h1>
		<div class="primarylinksheader"><?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links) ?><?php } ?></div>
	</div>
</div><!-- ENDE HEADER -->
<hr />

	


      				

	<div id="content" class="narrowcolumn"><!-- START CONTENT-->
		  <?php print $breadcrumb ?>
          <?php if ($title) { ?><h1 class="title"><?php print $title ?></h1><?php } ?>
          <?php if ($tabs) { ?><div class="tabs"><?php print $tabs ?></div><?php } ?>
          <?php print $help ?>
          <?php print $messages ?>
          <?php print $content; ?>
          <?php print $feed_icons; ?>		
  
	</div><!-- ENDE CONTENT -->



  	<div id="sidebar" class="wowsidebarright"><!-- START SIDEBAR-->
		<ul>
			<li>
			<?php if ($right) { ?><?php print $right ?><?php } ?> 
			</li>
		</ul>
	</div><!-- ENDE SIDEBAR -->






<div id="footer"><!-- START FOOTER -->

	<div style="padding-left:240px; text-align:center">
	  <p>
	  	<?php if ($footer_message) : ?>
	      <?php print $footer_message ?>
	    <?php endif ?>
		<br />
	    WebDesign by <a href="http://www.nunodesign.de/">nunodesign</a> &#124; <a href="http://www.randyrun.com">WoW Gold</a> Reseller &#124; ported to Drupal by <a href="http://www.mathiasdittrich.de">Mathias Dittrich</a>
  </p></div>
</div><!-- ENDE FOOTER -->

</div><!-- ENDE PAGE -->

</body>
</html>
